@@ -1,6 +1,6 @@
 use anyhow::Error;
 use fehler::throws;
-use trdelnik_sandbox_client::TestGenerator;
+use trdelnik_client::TestGenerator;
 
 #[throws]
 pub async fn init() {
