@@ -1,6 +1,6 @@
 use anyhow::Error;
 use fehler::throws;
-use trdelnik_sandbox_client::*;
+use trdelnik_client::*;
 
 #[throws]
 pub async fn test(root: String) {
